==> qlcplus_4.12.2.orig.tar.xz: qlcplus-QLC-_4.12.2/plugins/dmxusb/src/DMX_USB_fi_FI.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi_FI">
<context>
    <name>DMXUSB</name>
    <message>
        <location filename="dmxusb.cpp" line="139"/>
        <source>This plugin provides DMX output support for</source>
        <translation type="unfinished">Tämä liitännäinen tukee</translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="143"/>
        <source>and compatible devices.</source>
        <translation type="unfinished">Ei tunnistettuja laitteita.</translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="157"/>
        <source>No output support available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="159"/>
        <source>Make sure that you have your hardware firmly plugged in. NOTE: FTDI VCP interface is not supported by this plugin.</source>
        <translation type="unfinished">Varmista, että laitteisto on kytkettynä. Huomaa: Tämä liitännäinen ei tue FTDI VCP-interfacea.</translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="168"/>
        <location filename="dmxusb.cpp" line="271"/>
        <source>Device is operating correctly.</source>
        <translation type="unfinished">Laite toimii oikein.</translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="170"/>
        <source>Driver in use: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="258"/>
        <source>No input support available.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DMXUSBConfig</name>
    <message>
        <location filename="dmxusbconfig.cpp" line="47"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbconfig.cpp" line="48"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbconfig.cpp" line="55"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbconfig.cpp" line="55"/>
        <source>Serial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbconfig.cpp" line="55"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbconfig.cpp" line="55"/>
        <source>Output frequency</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EnttecDMXUSBOpen</name>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="117"/>
        <source>Protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="122"/>
        <source>DMX Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="125"/>
        <source>DMX Frame Frequency</source>
        <translation>DMX Framen taajuus</translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="129"/>
        <source>Bad</source>
        <translation>Huono</translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="131"/>
        <source>Good</source>
        <translation>Hyvä</translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="133"/>
        <source>Patch this widget to a universe to find out.</source>
        <translation>Kytke tämä laite johonkin universumiin selvittääksesi tilanteen.</translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="134"/>
        <source>System Timer Accuracy</source>
        <translation>Järjestelmän kellon tarkkuus</translation>
    </message>
</context>
<context>
    <name>EnttecDMXUSBPro</name>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="93"/>
        <location filename="enttecdmxusbpro.cpp" line="95"/>
        <source>Protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="98"/>
        <source>Manufacturer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="100"/>
        <source>Serial number</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="euroliteusbdmxpro.cpp" line="171"/>
        <location filename="nanodmx.cpp" line="236"/>
        <location filename="stageprofi.cpp" line="141"/>
        <location filename="vinceusbdmx512.cpp" line="47"/>
        <source>Protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="euroliteusbdmxpro.cpp" line="178"/>
        <location filename="nanodmx.cpp" line="243"/>
        <location filename="stageprofi.cpp" line="148"/>
        <location filename="vinceusbdmx512.cpp" line="51"/>
        <source>Serial number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="euroliteusbdmxpro.cpp" line="173"/>
        <location filename="nanodmx.cpp" line="238"/>
        <location filename="stageprofi.cpp" line="143"/>
        <location filename="vinceusbdmx512.cpp" line="49"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="119"/>
        <location filename="euroliteusbdmxpro.cpp" line="175"/>
        <location filename="nanodmx.cpp" line="240"/>
        <location filename="stageprofi.cpp" line="145"/>
        <source>Manufacturer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="236"/>
        <source>MIDI Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="238"/>
        <source>DMX Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="243"/>
        <source>MIDI Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="245"/>
        <source>DMX Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qlcplus_4.12.4.orig.tar.xz: qlcplus-QLC-_4.12.4/plugins/dmxusb/src/DMX_USB_fi_FI.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi_FI">
<context>
    <name>DMXUSB</name>
    <message>
        <location filename="dmxusb.cpp" line="139"/>
        <source>This plugin provides DMX output support for</source>
        <translation type="unfinished">Tämä liitännäinen tukee</translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="143"/>
        <source>and compatible devices.</source>
        <translation type="unfinished">Ei tunnistettuja laitteita.</translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="157"/>
        <source>No output support available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="159"/>
        <source>Make sure that you have your hardware firmly plugged in. NOTE: FTDI VCP interface is not supported by this plugin.</source>
        <translation type="unfinished">Varmista, että laitteisto on kytkettynä. Huomaa: Tämä liitännäinen ei tue FTDI VCP-interfacea.</translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="168"/>
        <location filename="dmxusb.cpp" line="272"/>
        <source>Device is operating correctly.</source>
        <translation type="unfinished">Laite toimii oikein.</translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="170"/>
        <location filename="dmxusb.cpp" line="274"/>
        <source>Driver in use: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusb.cpp" line="259"/>
        <source>No input support available.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DMXUSBConfig</name>
    <message>
        <location filename="dmxusbconfig.cpp" line="47"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbconfig.cpp" line="48"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbconfig.cpp" line="55"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbconfig.cpp" line="55"/>
        <source>Serial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbconfig.cpp" line="55"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbconfig.cpp" line="55"/>
        <source>Output frequency</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DMXUSBOpenRx</name>
    <message>
        <location filename="dmxusbopenrx.cpp" line="124"/>
        <source>Protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="130"/>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="132"/>
        <source>Idling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="134"/>
        <source>Calibrating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="136"/>
        <source>Receiving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="138"/>
        <source>Receiver state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="143"/>
        <source>Received DMX Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="148"/>
        <source>DMX Frame Frequency</source>
        <translation type="unfinished">DMX Framen taajuus</translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="154"/>
        <source>Bad</source>
        <translation type="unfinished">Huono</translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="156"/>
        <source>Good</source>
        <translation type="unfinished">Hyvä</translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="158"/>
        <source>Patch this widget to a universe to find out.</source>
        <translation type="unfinished">Kytke tämä laite johonkin universumiin selvittääksesi tilanteen.</translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="160"/>
        <source>System Timer Accuracy</source>
        <translation type="unfinished">Järjestelmän kellon tarkkuus</translation>
    </message>
</context>
<context>
    <name>EnttecDMXUSBOpen</name>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="118"/>
        <source>Protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="123"/>
        <source>DMX Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="126"/>
        <source>DMX Frame Frequency</source>
        <translation>DMX Framen taajuus</translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="130"/>
        <source>Bad</source>
        <translation>Huono</translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="132"/>
        <source>Good</source>
        <translation>Hyvä</translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="134"/>
        <source>Patch this widget to a universe to find out.</source>
        <translation>Kytke tämä laite johonkin universumiin selvittääksesi tilanteen.</translation>
    </message>
    <message>
        <location filename="enttecdmxusbopen.cpp" line="135"/>
        <source>System Timer Accuracy</source>
        <translation>Järjestelmän kellon tarkkuus</translation>
    </message>
</context>
<context>
    <name>EnttecDMXUSBPro</name>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="94"/>
        <location filename="enttecdmxusbpro.cpp" line="96"/>
        <source>Protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="99"/>
        <source>Manufacturer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="101"/>
        <source>Serial number</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="euroliteusbdmxpro.cpp" line="171"/>
        <location filename="nanodmx.cpp" line="236"/>
        <location filename="stageprofi.cpp" line="141"/>
        <location filename="vinceusbdmx512.cpp" line="47"/>
        <source>Protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="euroliteusbdmxpro.cpp" line="178"/>
        <location filename="nanodmx.cpp" line="243"/>
        <location filename="stageprofi.cpp" line="148"/>
        <location filename="vinceusbdmx512.cpp" line="51"/>
        <source>Serial number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="euroliteusbdmxpro.cpp" line="173"/>
        <location filename="nanodmx.cpp" line="238"/>
        <location filename="stageprofi.cpp" line="143"/>
        <location filename="vinceusbdmx512.cpp" line="49"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dmxusbopenrx.cpp" line="126"/>
        <location filename="enttecdmxusbopen.cpp" line="120"/>
        <location filename="euroliteusbdmxpro.cpp" line="175"/>
        <location filename="nanodmx.cpp" line="240"/>
        <location filename="stageprofi.cpp" line="145"/>
        <source>Manufacturer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="237"/>
        <source>MIDI Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="239"/>
        <source>DMX Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="244"/>
        <source>MIDI Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="enttecdmxusbpro.cpp" line="246"/>
        <source>DMX Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
